@@ -18,6 +18,7 @@
 */
 
 #include "common.h"
+#include "nut_platform.h"
 
 #include <pwd.h>
 #include <netdb.h>
@@ -316,3 +317,11 @@ int main(int argc, char **argv)
 
 	exit(EXIT_SUCCESS);
 }
+
+
+/* Formal do_upsconf_args implementation to satisfy linker on AIX */
+#if (defined NUT_PLATFORM_AIX)
+void do_upsconf_args(char *upsname, char *var, char *val) {
+        fatalx(EXIT_FAILURE, "INTERNAL ERROR: formal do_upsconf_args called");
+}
+#endif  /* end of #if (defined NUT_PLATFORM_AIX) */
