@@ -93,7 +93,7 @@
 #define LDOUBLE double
 #endif
 
-#ifdef HAVE_LONG_LONG
+#ifdef HAVE_LONG_LONG_INT
 #define LLONG long long
 #else
 #define LLONG long
