@@ -31,7 +31,22 @@
 
 #include "main.h"
 #include "serial.h"
-#include "bestuferrups.h"
+
+#define DRIVER_NAME	"Best Ferrups Series ME/RE/MD driver"
+#define DRIVER_VERSION	"0.03"
+
+/* driver description structure */
+upsdrv_info_t upsdrv_info = {
+	DRIVER_NAME,
+	DRIVER_VERSION,
+	"Andreas Wrede  <andreas@planix.com>\n" \
+	"John Stone  <johns@megapixel.com>\n" \
+	"Grant Taylor <gtaylor@picante.com>\n" \
+	"Russell Kroll <rkroll@exploits.org>\n" \
+	"Tim Thompson",
+	DRV_BETA, /* FIXME: STABLE? */
+	{ NULL }
+};
 
 #define ENDCHAR		'\r'
 #define IGNCHARS	"\012"
@@ -340,13 +355,6 @@ void upsdrv_help(void)
 {
 }
 
-
-void upsdrv_banner(void)
-{
-        printf("Network UPS Tools - Best Ferrups Series ME/RE/MD %s (%s)\n\n", 
-		DRV_VERSION, UPS_VERSION);
-}
-
 static void sync_serial(void) {
 	char buffer[10];
 
@@ -400,7 +408,7 @@ void upsdrv_initups ()
 
   fc.model = UNKNOWN;
   /* Obtain Model */
-  if (execute("id\r", fcstring, sizeof(fcstring)) < 0) {
+  if (execute("id\r", fcstring, sizeof(fcstring)) < 1) {
     fatalx(EXIT_FAILURE, "Failed execute in ups_ident()");
   }
   
