@@ -89,6 +89,9 @@ typedef struct reportbuf_s {
 
 extern reportbuf_t	*reportbuf;	/* buffer for most recent reports */
 
+extern int interrupt_only;
+extern unsigned int interrupt_size;
+
 /* ---------------------------------------------------------------------- */
 
 /*
