@@ -26,7 +26,7 @@
 #ifndef TRIPPLITE_HID_H
 #define TRIPPLITE_HID_H
 
-#include "newhidups.h"
+#include "usbhid-ups.h"
 
 extern subdriver_t tripplite_subdriver;
 
