@@ -30,7 +30,21 @@
 
 #include "main.h"
 #include "serial.h"
-#include "victronups.h"
+
+#define DRIVER_NAME	"GE/IMV/Victron UPS driver"
+#define DRIVER_VERSION	"0.20"
+
+/* driver description structure */
+upsdrv_info_t upsdrv_info = {
+	DRIVER_NAME,
+	DRIVER_VERSION,
+	"Russell Kroll <rkroll@exploits.org>\n" \
+	"Radek Benedikt <benedikt@lphard.cz>\n" \
+	"Daniel Prynych <Daniel.Prynych@hornet.cz>\n" \
+	"Gert Lynge <gert@lynge.org>",
+	DRV_STABLE,
+	{ NULL }
+};
 
 #define ENDCHAR	'\r'
 #define IGNCHARS "\n"
@@ -204,7 +218,6 @@ static int instcmd(const char *cmdname, const char *extra)
 void upsdrv_initinfo(void)
 {
        	
-	dstate_setinfo("driver.version.internal", "%s", DRV_VERSION);
 	if (model_name)
 		dstate_setinfo("ups.model", "%s", model_name);
 
@@ -225,7 +238,7 @@ void upsdrv_updateinfo(void)
 {
 	int flags; 
 	char temp[ LENGTH_TEMP ]; 
-	char test_result[ 255 ];
+	char test_result[ LENGTH_TEMP ];
 	int runtime_sec = -1;
 
         if (start_is_datastale)
@@ -501,12 +514,6 @@ void upsdrv_makevartable(void)
 	addvar(VAR_VALUE, "modelname", "Seting model name"); 
 }
 
-void upsdrv_banner(void)
-{
-	printf("Network UPS Tools - GE/IMV/Victron UPS driver %s (%s)\n\n",
-		DRV_VERSION, UPS_VERSION);
-}
-
 void upsdrv_initups(void)
 {
 	char temp[ LENGTH_TEMP ], *usd = NULL;  /* = NULL je dulezite jen pro prekladac */
@@ -516,13 +523,16 @@ void upsdrv_initups(void)
 	ser_set_speed(upsfd, device_path, B1200);
 
 
-	if ((usd = getval("usd"))) sdwdelay=atoi(usd);
-      
-	model_name = getval("modelname"); /* kdyz modelname nebylo zadano je vraceno NULL*/ 
+	if ((usd = getval("usd"))) {
+		sdwdelay=atoi(usd);
+		upsdebugx(1, "(-x) Delay before shutdown %i",sdwdelay);
+	}
+
+	if ((model_name = getval("modelname"))) {
+		/* kdyz modelname nebylo zadano je vraceno NULL*/ 
+		upsdebugx(1, "(-x) UPS Name %s",model_name);
+	}
 
-	upsdebugx(1, "(-x) Delay before shutdown %i",sdwdelay);
-	upsdebugx(1, "(-x) UPS Name %s",model_name);
-    
 	/* inicializace a synchronizace UPS */
 
 	ser_send_char(upsfd, ENDCHAR);
