@@ -17,24 +17,46 @@
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
 
-#ifndef SSL_H_SEEN
-#define SSL_H_SEEN 1
-
-#ifdef HAVE_SSL
-#include <openssl/err.h>
-#include <openssl/ssl.h>
-#endif
+#ifndef NETSSL_H_SEEN
+#define NETSSL_H_SEEN 1
 
 #include "nut_ctype.h"
 
+#ifdef __cplusplus
+/* *INDENT-OFF* */
+extern "C" {
+/* *INDENT-ON* */
+#endif
+
 extern char	*certfile;
+extern char	*certname;
+extern char	*certpasswd;
+#ifdef WITH_CLIENT_CERTIFICATE_VALIDATION
+extern int certrequest;
+#endif /* WITH_CLIENT_CERTIFICATE_VALIDATION */
+
+/* List possible values for certrequested */
+/* No request */
+#define NETSSL_CERTREQ_NO		0
+/* Requested (cnx failed if no certificate) */
+#define NETSSL_CERTREQ_REQUEST	1
+/* Required (cnx failed if no certificate or invalid CA chain) */
+#define NETSSL_CERTREQ_REQUIRE	2
+
 
 void ssl_init(void);
 void ssl_finish(nut_ctype_t *client);
+void ssl_cleanup(void);
 
 int ssl_read(nut_ctype_t *client, char *buf, size_t buflen);
 int ssl_write(nut_ctype_t *client, const char *buf, size_t buflen);
 
 void net_starttls(nut_ctype_t *client, int numarg, const char **arg);
 
-#endif	/* SSL_H_SEEN */
+#ifdef __cplusplus
+/* *INDENT-OFF* */
+}
+/* *INDENT-ON* */
+#endif
+
+#endif	/* NETSSL_H_SEEN */
