@@ -28,7 +28,7 @@
 #include "netuser.h"
 
 /* LOGIN <ups> */
-void net_login(ctype_t *client, int numarg, const char **arg)
+void net_login(nut_ctype_t *client, int numarg, const char **arg)
 {
 	upstype_t	*ups;
 
@@ -65,7 +65,7 @@ void net_login(ctype_t *client, int numarg, const char **arg)
 	sendback(client, "OK\n");
 }
 
-void net_logout(ctype_t *client, int numarg, const char **arg)
+void net_logout(nut_ctype_t *client, int numarg, const char **arg)
 {
 	if (numarg != 0) {
 		send_err(client, NUT_ERR_INVALID_ARGUMENT);
@@ -83,7 +83,7 @@ void net_logout(ctype_t *client, int numarg, const char **arg)
 }
 
 /* MASTER <upsname> */
-void net_master(ctype_t *client, int numarg, const char **arg)
+void net_master(nut_ctype_t *client, int numarg, const char **arg)
 {
 	upstype_t	*ups;
 
@@ -110,7 +110,7 @@ void net_master(ctype_t *client, int numarg, const char **arg)
 }
 
 /* USERNAME <username> */
-void net_username(ctype_t *client, int numarg, const char **arg)
+void net_username(nut_ctype_t *client, int numarg, const char **arg)
 {
 	if (numarg != 1) {
 		send_err(client, NUT_ERR_INVALID_ARGUMENT);
@@ -130,7 +130,7 @@ void net_username(ctype_t *client, int numarg, const char **arg)
 }
 
 /* PASSWORD <password> */
-void net_password(ctype_t *client, int numarg, const char **arg)
+void net_password(nut_ctype_t *client, int numarg, const char **arg)
 {
 	if (numarg != 1) {
 		send_err(client, NUT_ERR_INVALID_ARGUMENT);
