@@ -23,9 +23,16 @@
 #ifndef NUT_CTYPE_H_SEEN
 #define NUT_CTYPE_H_SEEN 1
 
-#ifdef HAVE_SSL
-#include <openssl/err.h>
-#include <openssl/ssl.h>
+/* Mozilla NSS */
+#ifdef WITH_NSS
+	#include <nss.h>
+	#include <ssl.h>
+#endif
+
+/* OpenSSL */
+#ifdef WITH_OPENSSL
+	#include <openssl/err.h>
+	#include <openssl/ssl.h>
 #endif
 
 #include "parseconf.h"
@@ -39,10 +46,12 @@ typedef struct nut_ctype_s {
 	char	*password;
 	char	*username;
 
-#ifdef	HAVE_SSL
+#ifdef	WITH_OPENSSL
 	SSL	*ssl;
+#elif defined(WITH_NSS)
+	PRFileDesc	*ssl;
 #else
-	void	*ssl;
+	void *ssl;
 #endif
 	int	ssl_connected;
 
