@@ -45,6 +45,12 @@
 
 #define NUT_NET_ANSWER_MAX SMALLBUF
 
+#ifdef __cplusplus
+/* *INDENT-OFF* */
+extern "C" {
+/* *INDENT-ON* */
+#endif
+
 /* prototypes from upsd.c */
 
 upstype_t *get_ups_ptr(const char *upsname);
@@ -85,4 +91,10 @@ extern nut_ctype_t	*firstclient;
 #define shutdown_how 2
 #endif
 
+#ifdef __cplusplus
+/* *INDENT-OFF* */
+}
+/* *INDENT-ON* */
+#endif
+
 #endif	/* UPSD_H_SEEN */
