@@ -1,6 +1,5 @@
-/* device.c: manipulation of a container describing a NUT device
- * 
- *  Copyright (C) 2011 - Frederic Bohe <fredericbohe@eaton.com>
+/*
+ *  Copyright (C) 2011 - EATON
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,6 +15,12 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
+
+/*! \file nutscan-device.c
+    \brief manipulation of a container describing a NUT device
+    \author Frederic Bohe <fredericbohe@eaton.com>
+*/
+
 #include "nutscan-device.h"
 #include <stdlib.h>
 #include <string.h>
