@@ -1,6 +1,5 @@
-/* ip.c: iterator for IPv4 or IPv6 addresses
- * 
- *  Copyright (C) 2011 - Frederic Bohe <fredericbohe@eaton.com>
+/*
+ *  Copyright (C) 2011 - EATON
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,6 +16,11 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
+/*! \file nutscan-ip.c
+    \brief iterator for IPv4 or IPv6 addresses
+    \author Frederic Bohe <fredericbohe@eaton.com>
+*/
+
 #include "nutscan-ip.h"
 #include <stdio.h>
 #include "common.h"
