@@ -1,7 +1,7 @@
 #!/usr/bin/env perl
 #   Current Version : 1.3
 #   Copyright (C) 2008 - 2012 dloic (loic.dardant AT gmail DOT com)
-#   Copyright (C) 2008 - 2014 Arnaud Quette <arnaud.quette@free.fr>
+#   Copyright (C) 2008 - 2015 Arnaud Quette <arnaud.quette@free.fr>
 #   Copyright (C) 2013 - 2014 Charles Lepple <clepple+nut@gmail.com>
 #
 #	Based on the usbdevice.pl script, made for the Ubuntu Media Center
@@ -111,9 +111,12 @@ sub gen_usb_files
 	open my $outputUPower, ">$outputUPower" || die "error $outputUPower : $!";
 	print $outputUPower '##############################################################################################################'."\n";
 	print $outputUPower '# Uninterruptible Power Supplies with USB HID interfaces'."\n#\n";
-	print $outputUPower '# to keep up to date, monitor https://github.com/networkupstools/nut/commits/master/scripts/upower/95-upower-hid.rules'."\n\n";
+	print $outputUPower '# This file was automatically generated by NUT:'."\n#".' https://github.com/networkupstools/nut/'."\n#\n";
+	print $outputUPower '# To keep up to date, monitor upstream NUT'."\n#".' https://github.com/networkupstools/nut/commits/master/scripts/upower/95-upower-hid.rules'."\n";
+	print $outputUPower "# or checkout the NUT repository and call 'tools/nut-usbinfo.pl'\n\n";
+	print $outputUPower '# newer hiddev are part of the usbmisc class'."\n".'SUBSYSTEM=="usbmisc", GOTO="up_hid_chkdev"'."\n";
 	print $outputUPower '# only support USB, else ignore'."\n".'SUBSYSTEM!="usb", GOTO="up_hid_end"'."\n\n";
-	print $outputUPower '# if usbraw device, ignore'."\n".'KERNEL!="hiddev*", GOTO="up_hid_end"'."\n\n";
+	print $outputUPower '# if usbraw device, ignore'."\n".'LABEL="up_hid_chkdev"'."\n".'KERNEL!="hiddev*", GOTO="up_hid_end"'."\n\n";
 	print $outputUPower '# if an interface, ignore'."\n".'ENV{DEVTYPE}=="usb_interface", GOTO="up_hid_end"'."\n\n";
 
 	# Device scanner header
